---
feature_story: FS_61_67_08_53
feature_title: non-searchable arg types
feature_status: TBD
---

Some arg types are non-searchable: there is no way to index their arg types as `data_envelope`-s.

For example, if there is a function to download a file,
remote file path is such an arg (arbitrary, not part of indexed data).

TODO: Figure out how to specify interrogation step for these arg types.
      At the moment, such args are provided without interrogation spec - user can simply add extra args
      to the command line. They will be sent to client on invocation and plugin client side can try
      to make use of them, but that is not good enough support for them.

# See also

Original issue: https://github.com/argrelay/argrelay/issues/46
